# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Location(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'latitude': 'float',
        'longitude': 'float',
        'arrival_duration': 'int',
        'departure_duration': 'int'
    }

    attribute_map = {
        'latitude': 'latitude',
        'longitude': 'longitude',
        'arrival_duration': 'arrival_duration',
        'departure_duration': 'departure_duration'
    }

    def __init__(self, latitude=None, longitude=None, arrival_duration=0, departure_duration=0, local_vars_configuration=None):  # noqa: E501
        """Location - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._latitude = None
        self._longitude = None
        self._arrival_duration = None
        self._departure_duration = None
        self.discriminator = None

        self.latitude = latitude
        self.longitude = longitude
        if arrival_duration is not None:
            self.arrival_duration = arrival_duration
        if departure_duration is not None:
            self.departure_duration = departure_duration

    @property
    def latitude(self):
        """Gets the latitude of this Location.  # noqa: E501

        Широта в градусах  # noqa: E501

        :return: The latitude of this Location.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this Location.

        Широта в градусах  # noqa: E501

        :param latitude: The latitude of this Location.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and latitude is None:  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                latitude is not None and latitude > 90):  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must be a value less than or equal to `90`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                latitude is not None and latitude < -90):  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must be a value greater than or equal to `-90`")  # noqa: E501

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this Location.  # noqa: E501

        Долгота в градусах  # noqa: E501

        :return: The longitude of this Location.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this Location.

        Долгота в градусах  # noqa: E501

        :param longitude: The longitude of this Location.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and longitude is None:  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                longitude is not None and longitude > 180):  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must be a value less than or equal to `180`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                longitude is not None and longitude < -180):  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must be a value greater than or equal to `-180`")  # noqa: E501

        self._longitude = longitude

    @property
    def arrival_duration(self):
        """Gets the arrival_duration of this Location.  # noqa: E501

        Время на подъезд (парковку) на локации в минутах  # noqa: E501

        :return: The arrival_duration of this Location.  # noqa: E501
        :rtype: int
        """
        return self._arrival_duration

    @arrival_duration.setter
    def arrival_duration(self, arrival_duration):
        """Sets the arrival_duration of this Location.

        Время на подъезд (парковку) на локации в минутах  # noqa: E501

        :param arrival_duration: The arrival_duration of this Location.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                arrival_duration is not None and arrival_duration > 1440):  # noqa: E501
            raise ValueError("Invalid value for `arrival_duration`, must be a value less than or equal to `1440`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                arrival_duration is not None and arrival_duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `arrival_duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._arrival_duration = arrival_duration

    @property
    def departure_duration(self):
        """Gets the departure_duration of this Location.  # noqa: E501

        Время на отъезд от локации в минутах  # noqa: E501

        :return: The departure_duration of this Location.  # noqa: E501
        :rtype: int
        """
        return self._departure_duration

    @departure_duration.setter
    def departure_duration(self, departure_duration):
        """Sets the departure_duration of this Location.

        Время на отъезд от локации в минутах  # noqa: E501

        :param departure_duration: The departure_duration of this Location.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                departure_duration is not None and departure_duration > 1440):  # noqa: E501
            raise ValueError("Invalid value for `departure_duration`, must be a value less than or equal to `1440`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                departure_duration is not None and departure_duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `departure_duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._departure_duration = departure_duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Location):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Location):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.predictor_api import PredictorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestPredictorApi(unittest.TestCase):
    """PredictorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.predictor_api.PredictorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_predictor_check(self):
        """Test case for predictor_check

        Проверка механизма подсказки временных окон.  # noqa: E501
        """
        pass

    def test_predictor_insert(self):
        """Test case for predictor_insert

        Добавление нового заказа.  # noqa: E501
        """
        pass

    def test_predictor_predict(self):
        """Test case for predictor_predict

        Подсказка временного окна  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.cargo import Cargo  # noqa: E501
from vrt_ud.rest import ApiException

class TestCargo(unittest.TestCase):
    """Cargo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Cargo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.cargo.Cargo()  # noqa: E501
        if include_optional :
            return Cargo(
                key = 'cargo01', 
                capacity = vrt_ud.models.capacity.Capacity(
                    mass = 10, 
                    volume = 2, 
                    capacity_x = 1, 
                    capacity_y = 2, 
                    capacity_z = 3, ), 
                width = 1, 
                height = 0.3, 
                length = 2.2, 
                max_storage_time = 45, 
                restrictions = ["Freezer"]
            )
        else :
            return Cargo(
                key = 'cargo01',
                capacity = vrt_ud.models.capacity.Capacity(
                    mass = 10, 
                    volume = 2, 
                    capacity_x = 1, 
                    capacity_y = 2, 
                    capacity_z = 3, ),
        )

    def testCargo(self):
        """Test Cargo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.data_api import DataApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clean_data(self):
        """Test case for clean_data

        Удаление данных за временной промежуток  # noqa: E501
        """
        pass

    def test_download_photo(self):
        """Test case for download_photo

        Скачивание фотографии по id  # noqa: E501
        """
        pass

    def test_find_photos(self):
        """Test case for find_photos

        Получение идентификаторов фотографий по фильтру  # noqa: E501
        """
        pass

    def test_load_data(self):
        """Test case for load_data

        Загрузка данных из файла в виде base64 строки  # noqa: E501
        """
        pass

    def test_load_data_file(self):
        """Test case for load_data_file

        Загрузка данных из файла  # noqa: E501
        """
        pass

    def test_read_orders(self):
        """Test case for read_orders

        Получение заказа по фильтру  # noqa: E501
        """
        pass

    def test_remove_orders(self):
        """Test case for remove_orders

        Удаление заказов по фильтру  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.tracks_result import TracksResult  # noqa: E501
from vrt_ud.rest import ApiException

class TestTracksResult(unittest.TestCase):
    """TracksResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TracksResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.tracks_result.TracksResult()  # noqa: E501
        if include_optional :
            return TracksResult(
                tracks = [
                    vrt_ud.models.performer_track.PerformerTrack(
                        shift_key = 'performer01', 
                        points = [
                            vrt_ud.models.track_point.TrackPoint(
                                latitude = 55.692789, 
                                longitude = 37.554554, 
                                timestamp = 56, )
                            ], 
                        last_point = vrt_ud.models.track_point.TrackPoint(
                            latitude = 55.692789, 
                            longitude = 37.554554, 
                            timestamp = 56, ), )
                    ]
            )
        else :
            return TracksResult(
        )

    def testTracksResult(self):
        """Test TracksResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
